@@ -1,5 +1,5 @@
 from quick_orm.core import Database
-from sqlalchemy import Column, String, Text
+from sqlalchemy import Column, String
 
 class User(object):
     __metaclass__ = Database.DefaultMeta
@@ -12,14 +12,14 @@ class Contact(object):
     address = Column(String(70))
 
 if __name__ == '__main__':
-    database = Database('sqlite://')
-    database.create_tables()
+    db = Database('sqlite://')
+    db.create_tables()
 
     contact = Contact(email = 'quick.orm.feedback@gmail.com', address = 'Shenzhen, China')
     user = User(name = 'Tyler Long', contact = contact)
-    database.session.add_then_commit(user)
+    db.session.add_then_commit(user)
     
-    user = database.session.query(User).get(1)
+    user = db.session.query(User).get(1)
     print 'User:', user.name
     print 'Email:', user.contact.email
     print 'Address:', user.contact.address
